"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.deleteFile = deleteFile;
exports.downloadAndExtractZip = void 0;
var _fsExtra = _interopRequireDefault(require("fs-extra"));
var _extractZip = _interopRequireDefault(require("extract-zip"));
var _path = _interopRequireDefault(require("path"));
var _rimraf = _interopRequireDefault(require("rimraf"));
var _clientS = require("@webiny/aws-sdk/client-s3");
var _download = _interopRequireDefault(require("./download"));
const PAGE_BUILDER_S3_BUCKET = process.env.S3_BUCKET;
const PAGE_BUILDER_INSTALLATION_FILES_ZIP_KEY = "pbInstallation.zip";
function extractZip(zipPath, dir) {
  return new Promise((resolve, reject) => {
    (0, _extractZip.default)(zipPath, {
      dir
    }, err => {
      if (err) {
        reject(err);
        return;
      }
      resolve();
    });
  });
}
function deleteFile(path) {
  return new Promise((resolve, reject) => {
    (0, _rimraf.default)(path, err => {
      if (err) {
        reject(err);
        return;
      }
      resolve();
    });
  });
}
const INSTALL_DIR = "/tmp";
const INSTALL_ZIP_PATH = _path.default.join(INSTALL_DIR, "apiPageBuilder.zip");
const INSTALL_EXTRACT_DIR = _path.default.join(INSTALL_DIR, "apiPageBuilder");
var _default = async () => {
  const s3 = new _clientS.S3({
    region: process.env.AWS_REGION
  });
  const installationFilesUrl = await (0, _clientS.getSignedUrl)(s3, new _clientS.GetObjectCommand({
    Bucket: PAGE_BUILDER_S3_BUCKET,
    Key: PAGE_BUILDER_INSTALLATION_FILES_ZIP_KEY
  }));
  _fsExtra.default.ensureDirSync(INSTALL_DIR);
  await (0, _download.default)(installationFilesUrl, INSTALL_ZIP_PATH);
  await extractZip(INSTALL_ZIP_PATH, INSTALL_EXTRACT_DIR);
  await deleteFile(INSTALL_ZIP_PATH);
  return INSTALL_EXTRACT_DIR;
};
exports.default = _default;
const downloadAndExtractZip = async ({
  zipFileKey,
  downloadZipAs,
  extractZipInDir,
  zipFileUrl
}) => {
  const s3 = new _clientS.S3({
    region: process.env.AWS_REGION
  });
  let installationFilesUrl;
  if (zipFileUrl) {
    installationFilesUrl = zipFileUrl;
  } else {
    installationFilesUrl = await (0, _clientS.getSignedUrl)(s3, new _clientS.GetObjectCommand({
      Bucket: PAGE_BUILDER_S3_BUCKET,
      Key: zipFileKey
    }));
  }
  _fsExtra.default.ensureDirSync(INSTALL_DIR);
  const zipPath = _path.default.join(INSTALL_DIR, downloadZipAs);
  const extractDir = _path.default.join(INSTALL_DIR, extractZipInDir);
  await (0, _download.default)(installationFilesUrl, zipPath);
  await extractZip(zipPath, extractDir);
  await deleteFile(zipPath);
  return extractDir;
};
exports.downloadAndExtractZip = downloadAndExtractZip;

//# sourceMappingURL=downloadInstallFiles.js.map